# README

[![PyPI](https://img.shields.io/pypi/v/delimux.svg)](https://pypi.org/project/delimux/)

## Installation

`pip install delimux`

## How to use and characteristics

The delimux can be used via the module `delimux`.

The usage is very simple:
```
import delimux
mx=delimux.DeliMUX()
help(mx)
```